# jasonpi

[![Build Status](https://travis-ci.org/gobadiah/jasonpi.svg?branch=master)](https://travis-ci.org/gobadiah/jasonpi)

Small python package for helping with authentication in django-rest-framework.
